//+------------------------------------------------------------------+
//|                                                       Sample.mq4 |
//|                                     Copyright (c) 2015, りゅーき |
//|                                           https://autofx100.com/ |
//+------------------------------------------------------------------+
#property copyright "Copyright (c) 2015, りゅーき"
#property link      "https://autofx100.com/"
#property version   "1.00"

//+------------------------------------------------------------------+
//| ライブラリ                                                       |
//+------------------------------------------------------------------+
#include <stderror.mqh>
#include <stdlib.mqh>
#include <WinUser32.mqh>
#include <Original/Basic.mqh>
#include <Original/DateAndTime.mqh>
#include <Original/LotSizing.mqh>
#include <Original/OrderHandle.mqh>
#include <Original/OrderReliable.mqh>

//+------------------------------------------------------------------+
//| EAパラメータ設定情報                                             |
//+------------------------------------------------------------------+
extern string Note01            = "=== General ==================================================";
extern int    MagicNumber       = 7777777;
extern int    SlippagePips      = 5;
extern double LotSize           = 0.01;
extern string Comments          = "";

extern string Note02            = "=== Entry ====================================================";
extern string Note02_1          = "--- entry only once per 1 bar --------------------------------";
extern bool   UseEntryPer1Bar   = true;

extern string Note03            = "=== Exit =====================================================";
extern string Note03_1          = "--- weekend exit ---------------------------------------------";
extern int    WeekendExitHour   = 23;
extern int    WeekendExitMinute = 30;
extern bool   IsJapanTime       = false; // サーバーが日本時刻ならtrue
extern int    EntryStopTime     = 120; // 分単位

//+------------------------------------------------------------------+
//| グローバル変数                                                   |
//+------------------------------------------------------------------+
// 共通
double gPipsPoint     = 0.0;
int    gSlippage      = 0;
color  gArrowColor[6] = {Blue, Red, Blue, Red, Blue, Red}; //BUY: Blue, SELL: Red
int    gPrvBars       = 0;

//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
{
  gPipsPoint = currencyUnitPerPips(Symbol());
  gSlippage = getSlippage(Symbol(), SlippagePips);

  gPrvBars = Bars;

  return(INIT_SUCCEEDED);
}

//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
{
}

//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
{
  int currentBars = Bars;

  // -----------------------------------------------------------------
  // 仕切り（週末指定時刻決済）
  // -----------------------------------------------------------------
  bool exitFlg = isWeekendExit(WeekendExitHour, WeekendExitMinute, IsJapanTime);

  if(exitFlg){
    allOrderClose(MagicNumber, gSlippage);
  }

  // -----------------------------------------------------------------
  // 仕掛けフィルター（１本の足で１回だけ仕掛ける）
  // -----------------------------------------------------------------
  if(UseEntryPer1Bar){
    // 新しい足を生成した時ではない場合は、仕掛けない
    if(currentBars == gPrvBars){
      gPrvBars = currentBars;
      return;
    }
  }

  // -----------------------------------------------------------------
  // 仕掛けフィルター（週末指定時刻決済の指定分前からの仕掛け中止）
  // -----------------------------------------------------------------
  bool entryStopFlg = isWeekendStopEntry(WeekendExitHour, WeekendExitMinute, IsJapanTime, EntryStopTime);

  if(entryStopFlg){
    return;
  }

  // -----------------------------------------------------------------
  // 仕掛け
  // -----------------------------------------------------------------
  // 成行注文
  if(Hour() == 21 && Minute() == 0){
    int ticket1 = orderSendReliable(Symbol(), OP_BUY, LotSize, Ask, gSlippage, 0.0, 0.0, Comments, MagicNumber, 0, gArrowColor[OP_BUY]);
  }

  // 金曜21:30は仕掛け不可
  if(Hour() == 21 && Minute() == 30){
    int ticket2 = orderSendReliable(Symbol(), OP_BUY, LotSize, Ask, gSlippage, 0.0, 0.0, Comments, MagicNumber, 0, gArrowColor[OP_BUY]);
  }

  // 金曜22:00も仕掛け不可
  if(Hour() == 22 && Minute() == 0){
    int ticket3 = orderSendReliable(Symbol(), OP_BUY, LotSize, Ask, gSlippage, 0.0, 0.0, Comments, MagicNumber, 0, gArrowColor[OP_BUY]);
  }

  // 本来はticketの値によって後続の処理を制御する必要があるが、簡単のため、ここでは無視

  gPrvBars = currentBars;
}
